@@ -1,5 +1,7 @@
 use fastobo::ast as obo;
 use fastobo::semantics::Identified;
+use horned_owl::model::Axiom;
+use horned_owl::model::Import;
 use horned_owl::model::MutableOntology;
 use horned_owl::model::Ontology;
 
@@ -58,6 +60,12 @@ impl IntoOwl for obo::OboDoc {
             ont.insert(axiom);
         }
 
+        // force import of the oboInOwl ontology
+        ont.insert(Axiom::Import(Import(
+            ctx.build
+                .iri("http://www.geneontology.org/formats/oboInOwl"),
+        )));
+
         // Convert each entity to a set of OWL axioms that are then added to the ontology.
         let entities = std::mem::replace(self.entities_mut(), Default::default());
         for entity in entities.into_iter() {
